@@ -50,7 +50,7 @@ exercises = ('chord',
              'sing-chord',
              'rhythm',
              'identify-bpm',
-             #'harmonic-progression-dictation'
+             'harmonic-progression-dictation'
              )
 
 msg1 = _("""Because not all documents has been
