@@ -25,6 +25,7 @@ import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
 
 import gtk, gnome
+import gobject
 import gu, widgets
 import soundcard, mpd, mpd.musicdisplayer
 import abstract, const, lessonfile
@@ -136,48 +137,43 @@ class Gui(abstract.LessonbasedGui):
         ################
         hbox = gu.bHBox(self.practise_box)
         hbox.set_spacing(gnome.ui.PAD)
+        spacebox = gtk.HBox()
+        hbox.pack_start(spacebox)
 
-        table = gtk.Table(5, 5, 0)
+        table = gtk.Table(4, 5, 0)
         hbox.pack_start(table, False)
         hsep = gtk.HSeparator()
         table.attach(hsep, 0, 5, 1, 2, xoptions=gtk.FILL,
                      yoptions=0, ypadding=gnome.ui.PAD_SMALL)
-        hsep = gtk.HSeparator()
-        table.attach(hsep, 0, 5, 3, 4, xoptions=gtk.FILL,
-                     yoptions=0, ypadding=gnome.ui.PAD_SMALL)
         vsep = gtk.VSeparator()
-        table.attach(vsep, 1, 2, 0, 5,
-                     xoptions=0, xpadding=gnome.ui.PAD_SMALL)
+        table.attach(vsep, 1, 2, 0, 4,
+                     xoptions=0, xpadding=gnome.ui.PAD)
         vsep = gtk.VSeparator()
-        table.attach(vsep, 3, 4, 0, 5,
-                     xoptions=0, xpadding=gnome.ui.PAD_SMALL)
+        table.attach(vsep, 3, 4, 0, 4,
+                     xoptions=0, xpadding=gnome.ui.PAD)
 
         table.attach(gtk.Label(_("Chord type")), 0, 1, 0, 1,
                      xoptions=gtk.FILL, yoptions=0)
         self.g_chordtype_box = gtk.VBox()
         table.attach(self.g_chordtype_box, 0, 1, 2, 3, xoptions=gtk.FILL)
-        self.g_type_status = gtk.Label("")
-        table.attach(self.g_type_status, 0, 1, 4, 5,
-                     xoptions=gtk.FILL, yoptions=0)
 
         table.attach(gtk.Label(_("Inversion")), 2, 3, 0, 1,
                      xoptions=gtk.FILL, yoptions=0)
         self.g_inversion_box = gtk.VBox()
         table.attach(self.g_inversion_box, 2, 3, 2, 3, xoptions=gtk.FILL)
-        self.g_inversion_status = gtk.Label("")
-        table.attach(self.g_inversion_status, 2, 3, 4, 5,
-                     xoptions=gtk.FILL, yoptions=0)
 
         table.attach(gtk.Label(_("Toptone")), 4, 5, 0, 1,
                      xoptions=gtk.FILL, yoptions=0)
         self.g_toptone_box = gtk.VBox()
         table.attach(self.g_toptone_box, 4, 5, 2, 3, xoptions=gtk.FILL)
-        self.g_toptone_status = gtk.Label("")
-        table.attach(self.g_toptone_status, 4, 5, 4, 5,
-                     xoptions=gtk.FILL, yoptions=0)
 
         self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
-        hbox.pack_start(self.g_music_displayer)
+        self.g_music_displayer.set_size_request(100, -1)
+        hbox.pack_start(self.g_music_displayer, False)
+        spacebox = gtk.HBox()
+        hbox.pack_start(spacebox)
+        self.g_flashbar = gu.FlashBar()
+        self.practise_box.pack_start(self.g_flashbar, False)
 
         self.g_new = gu.bButton(self.action_area, _("_New chord"),
                                 self.new_question)
@@ -209,6 +205,8 @@ class Gui(abstract.LessonbasedGui):
         if self.m_t.m_P:
             for ctype, translated_type in self.m_t.m_P.m_chord_types.iteritems():
                 b = gtk.Button(translated_type)
+                sr = b.size_request()
+                b.set_size_request(int(sr[0]*1.3), sr[1])
                 b.set_data('type', ctype)
                 b.connect('clicked', self.on_type)
                 b.connect('button_release_event', self.on_type)
@@ -222,6 +220,8 @@ class Gui(abstract.LessonbasedGui):
                 else:
                     s = _("%i. inversion") % x
                 b = gtk.Button(s)
+                sr = b.size_request()
+                b.set_size_request(int(sr[0]*1.3), sr[1])
                 b.set_data('inversion', x)
                 b.connect('clicked', self.on_inversion)
                 b.connect('button_release_event', self.on_inversion)
@@ -247,9 +247,6 @@ class Gui(abstract.LessonbasedGui):
         self.g_repeat_arpeggio.set_sensitive(False)
         self.g_give_up.set_sensitive(False)
         self.update_answer_buttons()
-        self.g_type_status.set_text('')
-        self.g_inversion_status.set_text('')
-        self.g_toptone_status.set_text('')
         self.g_win.set_title("Solfege - " + self.get_pretty_name())
     def on_type(self, button, event=None):
         if event is None:
@@ -263,14 +260,14 @@ class Gui(abstract.LessonbasedGui):
             return
         g = self.m_t.guess_type(button.get_data('type'))
         if g:
-            self.g_type_status.set_text(_("Correct"))
+            self.g_flashbar.flash(_("Correct"))
             for b in self.g_chordtype_box.get_children():
                 if b == button:
                     b.get_children()[0].set_name("Bold")
             if g == self.m_t.ALL_CORRECT:
                 self.all_guessed_correct()
         else:
-            self.g_type_status.set_text(_("Wrong"))
+            self.g_flashbar.flash(_("Wrong"))
         if self.m_t.m_correct == [1, 1, 1]:
             self.show_answer()
             self.g_new.set_sensitive(True)
@@ -327,12 +324,12 @@ class Gui(abstract.LessonbasedGui):
           or self.m_t.m_correct[1]:
             return
         if self.m_t.guess_inversion(button.get_data('inversion')):
-            self.g_inversion_status.set_text(_("Correct"))
+            self.g_flashbar.flash(_("Correct"))
             for b in self.g_inversion_box.get_children():
                 if b == button:
                     b.get_children()[0].set_name("Bold")
         else:
-            self.g_inversion_status.set_text(_("Wrong"))
+            self.g_flashbar.flash(_("Wrong"))
         if self.m_t.m_correct == [1, 1, 1]:
             self.show_answer()
             self.g_new.set_sensitive(True)
@@ -394,12 +391,12 @@ class Gui(abstract.LessonbasedGui):
            or self.m_t.m_correct[2]:
             return
         if self.m_t.guess_toptone(button.get_data('toptone')):
-            self.g_toptone_status.set_text(_("Correct"))
+            self.g_flashbar.flash(_("Correct"))
             for b in self.g_toptone_box.get_children():
                 if b == button:
                     b.get_children()[0].set_name("Bold")
         else:
-            self.g_toptone_status.set_text(_("Wrong"))
+            self.g_flashbar.flash(_("Wrong"))
         if self.m_t.m_correct == [1, 1, 1]:
             self.show_answer()
             self.g_new.set_sensitive(True)
@@ -436,9 +433,6 @@ class Gui(abstract.LessonbasedGui):
                 if self.get_bool('config/picky_on_new_question'):
                     self.g_new.set_sensitive(False)
                 self.g_repeat_arpeggio.set_sensitive(True)
-                self.g_type_status.set_text('')
-                self.g_inversion_status.set_text('')
-                self.g_toptone_status.set_text('')
                 self.g_inversion_box.set_sensitive(self.m_t.m_P.get_inversion() != -1)
                 self.g_toptone_box.set_sensitive(self.m_t.m_P.get_toptone() != -1)
                 self.g_chordtype_box.get_children()[0].grab_focus()
@@ -454,6 +448,8 @@ class Gui(abstract.LessonbasedGui):
                 self.m_t.m_P._idx, self.get_string('lessonfile'), e)
     def on_start_practise(self):
         self.g_new.grab_focus()
+        gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
+            self.g_flashbar.flash(_("Click 'New chord' to begin.")))
     def on_end_practise(self):
         self.m_t.end_practise()
         self.g_music_displayer.clear()
@@ -461,22 +457,20 @@ class Gui(abstract.LessonbasedGui):
         self.g_repeat.set_sensitive(False)
         self.g_repeat_arpeggio.set_sensitive(False)
         self.g_give_up.set_sensitive(False)
-        self.g_type_status.set_text('')
-        self.g_inversion_status.set_text('')
-        self.g_toptone_status.set_text('')
     def give_up(self, widget=None):
         if self.m_t.q_status == const.QSTATUS_NEW:
             self.m_t.give_up()
             self.show_answer()
-            self.g_type_status.set_text(self.m_t.m_P.m_chord_types[self.m_t.m_P.get_cname()])
+            type_txt = self.m_t.m_P.m_chord_types[self.m_t.m_P.get_cname()]
             i = self.m_t.m_P.get_inversion()
             if i == 0:
-                self.g_inversion_status.set_text(_("root position"))
+                inversion_txt = _("root position")
             elif i > 0:
-                self.g_inversion_status.set_text(_("%i. inversion") % i)
+                inversion_txt = _("%i. inversion") % i
             i = self.m_t.m_P.get_toptone()
             if i != -1:
-                self.g_toptone_status.set_text("%i" % i)
+                toptone_txt = "toptone: %i" % i
+            self.g_flashbar.flash(_("%s, %s and %s") % (type_txt, inversion_txt, toptone_txt))
             self.g_new.set_sensitive(True)
             self.g_give_up.set_sensitive(False)
             for button in self.g_chordtype_box.get_children():
