@@ -120,7 +120,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_sex_male = gtk.RadioButton(None, _("_Male"))
         self.g_sex_male.connect('toggled', lambda w: self.set_string('user/sex', 'male'))
         category_vbox.pack_start(self.g_sex_male, False)
-        self.g_sex_female = gtk.RadioButton(self.g_sex_male, _("_Female"))
+        self.g_sex_female = gtk.RadioButton(self.g_sex_male, _("_Female or child"))
         self.g_sex_female.connect('toggled', lambda w: self.set_string('user/sex', 'female'))
         category_vbox.pack_start(self.g_sex_female, False)
         if self.get_string('user/sex') == 'female':
