@@ -26,7 +26,7 @@ exercise_setup.register_exercise(__exercise_data__)
 
 import inputwidgets, abstract, const, random, soundcard, gu, mpd, gnome
 import gobject
-import configureoutput
+import runtime
 import gtk
 import gu
 import statistics, statisticsviewer
@@ -60,6 +60,8 @@ class Teacher(abstract.Teacher):
                 and (not self.get_bool('one_chance_only')):
             return Teacher.ERR_PICKY
 
+        self.m_is_first_question = self.q_status == const.QSTATUS_NO
+
         v = []
         for n in ['c', 'cis', 'd', 'dis', 'e', 'f', 'fis',
                   'g', 'gis', 'a', 'ais', 'b']:
@@ -108,7 +110,7 @@ class Teacher(abstract.Teacher):
 class Gui(abstract.Gui):
     def __init__(self, teacher, window):
         abstract.Gui.__init__(self, teacher, window)
-        if not configureoutput.WITH_GNOME:
+        if not runtime.has_gnome_canvas():
             self.practise_box.add(gtk.Label(_(
 """This exercise doesn't work without GNOME.
 It can pretty easy be converted to use Pixmap instead
@@ -205,12 +207,14 @@ _("""You have to select some tones practise. Do this on the config page by setti
             self.g_new_tone.set_sensitive(
                   not self.get_bool('config/picky_on_new_question'))
             self.g_repeat.set_sensitive(True)
-            if s in (const.QSTATUS_NO, const.QSTATUS_GIVE_UP):
-                self.g_flashbar.flash(_("First tone is %s")
-                                      % self.m_t.m_question)
+            if self.m_t.m_is_first_question:
+                self.flash_and_play_first_tone()
             self.g_flashbar.clear()
             self.m_t.play_question()
         self.set_percentage_label()
+    def flash_and_play_first_tone(self):
+        self.g_flashbar.flash(_("First tone is %s") % self.m_t.m_question)
+        self.m_t.play_question()
     def on_answer_from_user(self, notename):
         if self.m_t.q_status == const.QSTATUS_NO:
             self.g_flashbar.flash(_("Click 'New tone' to begin."))
@@ -226,6 +230,9 @@ _("""You have to select some tones practise. Do this on the config page by setti
                 self.g_new_tone.set_sensitive(True)
                 self.g_give_up.set_sensitive(False)
             else:
+                if self.m_t.m_is_first_question:
+                    self.flash_and_play_first_tone()
+                    return
                 self.g_flashbar.flash(_("Wrong"))
                 if self.get_bool('one_chance_only'):
                     self.m_t.new_question()
@@ -255,7 +262,7 @@ _("""You have to select some tones practise. Do this on the config page by setti
     def set_percentage_label(self):
         self.g_percentage.set_text("%.1f %%" % (self.m_t.m_statistics.get()*100))
     def on_start_practise(self):
-        if not configureoutput.WITH_GNOME:
+        if not runtime.has_gnome_canvas():
             return # this exercise don't work without GnomeCanvas
         self.m_t.m_statistics.reset_session()
         self.set_percentage_label()
@@ -268,5 +275,5 @@ _("""You have to select some tones practise. Do this on the config page by setti
         self.m_t.q_status = const.QSTATUS_NO
     def on_end_practise(self):
         self.m_t.end_practise()
-        if configureoutput.WITH_GNOME:
+        if runtime.has_gnome_canvas():
             self.g_repeat.set_sensitive(False)
