@@ -15,8 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-from __future__ import generators
-
 try:
     app_running == True
 except:
@@ -26,6 +24,8 @@ except:
     import i18n
     i18n.setup_srcdir()
 
+import xrandom
+
 class LessonfileException(Exception):
     def get_title(self):
         return "LessonfileException"
@@ -139,6 +139,8 @@ class _Header:
                            ('questions_selectable', False),
                            ('have_repeat_slowly_button', False),
                            ('have_repeat_arpeggio_button', False),
+                           ('have_play_music_button', False),
+                           ('have_display_music_button', False),
                            ('have_music_displayer', False),
                            ('enable_right_click', True),
                            ):
@@ -179,11 +181,21 @@ class LessonfileCommon(object):
                 # The following line is for backward compatibility
                 question['music'] = Music(question['music'], self.header.musicformat)
             question['m_lessonfile'] = self
+        self.m_random = xrandom.Random(range(len(self.m_questions)))
     def select_random_question(self):
         """
         Select a new question by random. It will use the music in the
         lesson file question variable 'music' when selecting transposition.
         """
+        # when we start the program with --no-random, we want to go
+        # throug all the questions in the lesson file in sequential order.
+        if cfg.get_bool('config/no_random'):
+            try:
+                self.m_no_random_idx
+            except:
+                self.m_no_random_idx = 0
+            self.header.random_transpose = False
+
         count = 0
         available_question_idx = []
         if not self.m_questions:
@@ -195,7 +207,21 @@ class LessonfileCommon(object):
             raise NoQuestionConfiguredException()
         while 1:
             count += 1
-            self._idx = random.choice(available_question_idx)
+            if cfg.get_bool('config/no_random'):
+                if self.m_no_random_idx < len(available_question_idx):
+                    self._idx = self.m_no_random_idx
+                    self.m_no_random_idx += 1
+                else:
+                    self._idx = self.m_no_random_idx = 0
+            else:
+                if cfg.get_string("app/random_function") == 'random_by_random':
+                    self._idx = self.m_random.random_by_random(available_question_idx)
+                elif cfg.get_string("app/random_function") == 'random_by_random2':
+                    self._idx = self.m_random.random_by_random2(available_question_idx)
+                elif cfg.get_string("app/random_function") == 'random_by_selection':
+                    self._idx = self.m_random.random_by_selection(available_question_idx)
+                else:
+                    self._idx = random.choice(available_question_idx)
             if self.header.random_transpose:
                 if self.header.random_transpose == True:
                     self.handle_random_transpose_is_yes()
@@ -220,6 +246,7 @@ class LessonfileCommon(object):
                 and (len(self.m_questions) > 1 or self.header.random_transpose):
                 continue
             break
+        self.m_random.add(self._idx)
         self.m_prev_question = self.get_music()
     def semitone_find_random_transpose(self):
         """
@@ -359,14 +386,13 @@ class LessonfileCommon(object):
             return question[varname].m_musicdata
         else:
             raise LessonfileException("\nUknown music type: '%s'" % question[varname].m_musictype)
-    def get_music(self):
+    def get_music(self, varname='music'):
         """
         Return the music for the currently selected question. This is complete
         music code that can be fed to mpd.play_music(...).
-        FIXMEFIXME Currently this returns the MUSIC variable.
         """
         assert self._idx is not None
-        return self.prepare_music_from_string(self.m_questions[self._idx], 'music')
+        return self.prepare_music_from_string(self.m_questions[self._idx], varname)
     def prepare_music_string_satb_format(self, question, varname):
         """
         It should not be necessary to call this method directly. Call
@@ -458,33 +484,33 @@ class LessonfileCommon(object):
                 self.m_t.get_string('lessoncollections/%s' % self.m_t.get_string('lessoncollection')),
                 question[varname].m_musicdata))
         elif question[varname].m_musictype in ('normal', 'satb', 'voice', 'rvoice'):
-            self.play_question_musicformat_normal_satb(question)
-        elif question[varname].m_musictype == 'chord':
-            self.play_question_musicformat_chord(question)
+            self.play_question_musicformat_normal_satb(question, varname)
+        elif question[varname].m_musictype in 'chord':
+            self.play_question_musicformat_chord(question, varname)
         else:
             raise LessonfileException("Unrecognised musictype '%s'" % question[varname].m_musictype)
-    def play_question_musicformat_normal_satb(self, question):
+    def play_question_musicformat_normal_satb(self, question, varname):
         instrument = self.prepare_instrument_list(question)
-        mpd.play_music(question.get_music(), self.get_tempo(),
+        mpd.play_music(question.get_music(varname), self.get_tempo(),
                        instrument[0], instrument[1])
-    def play_question_slowly(self, question=None):
+    def play_question_slowly(self, question=None, varname='music'):
         if not question:
             question = self.get_question()
         #assert question['music'].m_musictype == 'normal'
         #FIXME what music types should be handled differently
-        self.play_question_musicformat_normal_slowly(question)
-    def play_question_musicformat_normal_slowly(self, question):
+        self.play_question_musicformat_normal_slowly(question, varname)
+    def play_question_musicformat_normal_slowly(self, question, varname='music'):
         instrument = self.prepare_instrument_list(question)
         bpm = self.get_tempo()
         bpm = (bpm[0]/2, bpm[1])
-        mpd.play_music(question.get_music(), bpm,
+        mpd.play_music(question.get_music(varname), bpm,
                        instrument[0], instrument[1])
     def play_question_musicformat_chord(self, question, varname='music'):
-        assert question['music'].m_musictype == 'chord'
+        assert question[varname].m_musictype == 'chord'
         instrument = self.prepare_instrument_list(question)
         assert len(instrument) in (2, 6)
         if len(instrument) == 2:
-            mpd.play_music(question.get_music(), self.get_tempo(),
+            mpd.play_music(question.get_music(varname), self.get_tempo(),
                        instrument[0], instrument[1])
         else:
             assert len(instrument) == 6
@@ -546,10 +572,9 @@ class LessonfileCommon(object):
                                     instrument[3])
             track.note(4, len(nlist)-1, mpd.notename_to_int(nlist[-1]), instrument[5])
             soundcard.synth.play_track(track)
-    def play_question_musicformat_satb_arpeggio(self):
+    def play_question_musicformat_satb_arpeggio(self, varname='music'):
         """FIXME -- for completeness, should this function should take a question argument?
         """
-        varname = 'music'
         instrument = self.prepare_instrument_list(self.get_question())
         track = soundcard.Track()
         track.set_bpm(cfg.get_int('config/default_bpm'))
@@ -571,13 +596,13 @@ class LessonfileCommon(object):
                 else:
                     track.note(4, 0, mpd.notename_to_int(n)+12, instrument[1])
         soundcard.synth.play_track(track)
-    def play_question_as_choral(self, question):
+    def play_question_as_choral(self, question, varname='music'):
         instrument = self.prepare_instrument_list(self.get_question())
         if len(instrument) == 2:
             instrument = instrument * 3
         # FIXME, only the velocity from instrument[1] is used since
         # music_to_tracklist is not complete.
-        tracklist = mpd.music_to_tracklist(question.get_music(), instrument[1])
+        tracklist = mpd.music_to_tracklist(question.get_music(varname), instrument[1])
         tracklist[0].prepend_patch(0, instrument[4])
         track = tracklist[0]
         a, b = self.get_tempo()
