@@ -42,7 +42,7 @@ class SelectLessonfileWidget(gtk.VBox):
         self.g_title.set_line_wrap(True)
         box = gu.hig_label_widget(_("Title:"), self.g_title, None)
         category_vbox.pack_start(box, False)
-        btn = gtk.Button("Change lesson file ...")
+        btn = gtk.Button(_("Change lesson file ..."))
         btn.connect('clicked', self.on_change_lessonfile_clicked)
         box.pack_start(btn, False)
         self.desc_button = gtk.Button()
@@ -55,16 +55,14 @@ class SelectLessonfileWidget(gtk.VBox):
         self.description_visible = 0
         self.g_desc_arrow = gtk.Arrow(gtk.ARROW_RIGHT, gtk.SHADOW_IN)
         hbox.pack_start(self.g_desc_arrow, False)
-        hbox.pack_start(gtk.Label("Details"), False)
+        hbox.pack_start(gtk.Label(_("Details")), False)
         hbox.pack_start(gtk.HSeparator())
         # collection
-        self.g_lessoncollection = gtk.Entry()
-        self.g_lessoncollection.set_editable(False)
+        self.g_lessoncollection = gtk.Label()
         self.g_lessoncollection_box = gu.hig_label_widget(_("Lesson collection:"), self.g_lessoncollection, sizegroup)
         category_vbox.pack_start(self.g_lessoncollection_box, False)
         # filename
-        self.g_lessonfile = gtk.Entry()
-        self.g_lessonfile.set_editable(False)
+        self.g_lessonfile = gtk.Label()
         self.g_lessonfile_box = gu.hig_label_widget(_("Filename:"), self.g_lessonfile, sizegroup)
         category_vbox.pack_start(self.g_lessonfile_box, False)
         # description
@@ -171,7 +169,7 @@ class FileSelectDialog(gtk.Dialog):
         # select collection
         content_vbox = gu.hig_dlg_vbox()
         self.vbox.pack_start(content_vbox)
-        box, category_content_vbox = gu.hig_category_vbox("Lesson collection")
+        box, category_content_vbox = gu.hig_category_vbox(_("Lesson collection"))
         content_vbox.pack_start(box)
         hbox = gtk.HBox()
         category_content_vbox.pack_start(hbox, False)
@@ -197,14 +195,14 @@ class FileSelectDialog(gtk.Dialog):
         scrolledwin.add(self.g_treeview)
         scrolledwin.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         scrolledwin.set_size_request(600, 300)
-        box, vb = gu.hig_category_vbox("Select file")
+        box, vb = gu.hig_category_vbox(_("Select lesson file"))
         content_vbox.pack_start(box, True)
         vb.pack_start(scrolledwin)
     
-        column = gtk.TreeViewColumn('Filename', gtk.CellRendererText(),
+        column = gtk.TreeViewColumn(_('Filename'), gtk.CellRendererText(),
                                      text=0)
         self.g_treeview.append_column(column)
-        column = gtk.TreeViewColumn('Description', gtk.CellRendererText(),
+        column = gtk.TreeViewColumn(_('Description'), gtk.CellRendererText(),
                                      text=1)
         self.g_treeview.append_column(column)
         if current_filenum >= 0:
