@@ -1,4 +1,4 @@
-#!/usr/bin/python2.2
+#!/usr/bin/python2.3
 
 import pygtk
 pygtk.require("2.0")
@@ -81,10 +81,10 @@ class DisplaytestWindow(gtk.Window):
 
 
 #soundcard.initialise_devicefile("/dev/sequencer", 0)
-soundcard.initialise_devicefile("/dev/music", 0)
-#soundcard.initialise_using_fake_synth()
+#soundcard.initialise_devicefile("/dev/music", 0)
+soundcard.initialise_using_fake_synth()
 
 w = DisplaytestWindow()
-w.connect('destroy', gtk.mainquit)
+w.connect('destroy', gtk.main_quit)
 w.show()
-gtk.mainloop()
+gtk.main()
